@@ -37,12 +37,11 @@ function(x,comps=c(1,2),colors=list(scores="#0000AA",loadings="red",background="
   plotloadings$V3 <- rep(0,npl)
   plotloadings$V4 <- plotloadings$V1+sign(plotloadings$V1)* labelpos
   plotloadings$V5 <- plotloadings$V2+sign(plotloadings$V2)* labelpos
-  localenv <- environment()
-  plotty <- ggplot(environment=localenv)
+  plotty <- ggplot()
   plotty <- plotty + geom_text(data=plotscores, aes_string(x=colnames(plotscores)[1],y=colnames(plotscores)[2]), size=textsize,label=rownames(plotscores),color=colors$scores) 
   plotty <- plotty + labs(title=paste(names(x$YMeans)," Sparse PRM Components ", c1," and ",c2," Biplot"),x=colnames(plotscores)[1],y=colnames(plotscores)[2])
-  plotty <- plotty + geom_segment(data=plotloadings,aes(x=V3,y=V3,xend=V1,yend=V2),color=colors$loadings,arrow=arrow(angle=arrowshapes[1],length=unit(arrowshapes[2],"npc")),environment=localenv,na.rm=TRUE)
-  plotty <- plotty + geom_text(data=plotloadings,aes(x=V4,y=V5),color=colors$loadings,label=rownames(plotloadings),size=textsize,environment=localenv,na.rm=TRUE)
+  plotty <- plotty + geom_segment(data=plotloadings,aes(x=V3,y=V3,xend=V1,yend=V2),color=colors$loadings,arrow=ggplot2::arrow(angle=arrowshapes[1],length=ggplot2::unit(arrowshapes[2],"npc")),na.rm=TRUE)
+  plotty <- plotty + geom_text(data=plotloadings,aes(x=V4,y=V5),color=colors$loadings,label=rownames(plotloadings),size=textsize,na.rm=TRUE)
   plotty <- plotty + theme(panel.background=element_rect(fill=colors$background),plot.title=element_text(size=rel(1.5),face="bold"))
   print(plotty)
 }
\ No newline at end of file
